# Kidash

Kidash is a prototype of a tool for managing Kibana dashboards from the command line. It is a part of [GrimoireLab](https://grimoirelab.github.io).

## Source code

The source code is for now a part of [GrimoireELK](https://github.com/grimoirelab/grimoireelk).

